Serf Membership
=======

This is very simle script for election a leader (primary) from all members tagget with specific role.

#Copyright
Copyright (c) 2016 Marian Ignev. See LICENSE for further details.
